Savanna image elements project
==============================

This repo is a place for Savanna-related for diskimage-builder elements.

Script for creating Fedora and Ubuntu cloud images with our elements and default parameters. You should only need to run this command:

.. sourcecode:: bash

    sudo bash diskimage-create.sh

Note: More information about script `diskimage-create <https://github.com/openstack/savanna-image-elements/blob/master/diskimage-create/README.rst>`_
